[gimp] pdb: Modify gimp-selection-border to use BORDER_STYLE_SMOOTH



commit 2f96950eaa2cd866a1078b67de2c77f95d947e17
Author: Ell <ell_se yahoo com>
Date:   Mon Apr 4 16:07:06 2016 +0000

    pdb: Modify gimp-selection-border to use BORDER_STYLE_SMOOTH
    
    instead of BORDER_STYLE_FEATHERD.
    
    Changes the behavior of the function, but probably for the better.
    
    This, and the previous 5 commits, fix bug 764614.

 app/pdb/selection-cmds.c       |    4 ++--
 tools/pdbgen/pdb/selection.pdb |    4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)
---
diff --git a/tools/pdbgen/pdb/selection.pdb b/tools/pdbgen/pdb/selection.pdb
index ee22d02..bac88bb 100644
--- a/tools/pdbgen/pdb/selection.pdb
+++ b/tools/pdbgen/pdb/selection.pdb
@@ -360,10 +360,10 @@ HELP
     %invoke = (
        code => <<'CODE'
 {
-  /* FIXME: "style" and "edge-lock" hardcoded to FEATHERED and TRUE, respectively. */
+  /* FIXME: "style" and "edge-lock" hardcoded to SMOOTH and TRUE, respectively. */
   gimp_channel_border (gimp_image_get_mask (image),
                        radius, radius,
-                       GIMP_CHANNEL_BORDER_STYLE_FEATHERED,
+                       GIMP_CHANNEL_BORDER_STYLE_SMOOTH,
                        TRUE, TRUE);
 }
 CODE


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/app/pdb/selection-cmds.c b/app/pdb/selection-cmds.c
index 781bb62..cf3a306 100644
--- a/app/pdb/selection-cmds.c
+++ b/app/pdb/selection-cmds.c
@@ -362,10 +362,10 @@ selection_border_invoker (GimpProcedure         *procedure,
 
   if (success)
     {
       /* FIXME: "style" and "edge-lock" hardcoded to FEATHERED and TRUE, respectively. */
       gimp_channel_border (gimp_image_get_mask (image),
                            radius, radius,
-                           GIMP_CHANNEL_BORDER_STYLE_FEATHERED,
+                           GIMP_CHANNEL_BORDER_STYLE_SMOOTH,
                            TRUE, TRUE);
     }
 
@@ -362,10 +362,10 @@ selection_border_invoker (GimpProcedure         *procedure,
   if (success)
     {
-      /* FIXME: "style" and "edge-lock" hardcoded to FEATHERED and TRUE, respectively. */
+      /* FIXME: "style" and "edge-lock" hardcoded to SMOOTH and TRUE, respectively. */
       gimp_channel_border (gimp_image_get_mask (image),
                            radius, radius,